package com.jiuqi.util.zip;

import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;
import java.util.NoSuchElementException;
import java.util.Vector;
import java.util.zip.ZipException;

/* loaded from: com_jiuqi_util_zip.jar:com/jiuqi/util/zip/ZipEntry.class */
public class ZipEntry extends java.util.zip.ZipEntry implements Cloneable {
    private static final int PLATFORM_UNIX = 3;
    private static final int PLATFORM_FAT = 0;
    private int internalAttributes;
    private int platform;
    private long externalAttributes;
    private Vector extraFields;
    private String name;
    private Long compressedSize;
    private static Method setCompressedSizeMethod = null;
    private static Object lockReflection = new Object();
    private static boolean triedToGetMethod = false;

    public ZipEntry(String name) {
        super(name);
        this.internalAttributes = 0;
        this.platform = 0;
        this.externalAttributes = 0L;
        this.extraFields = new Vector();
        this.name = null;
        this.compressedSize = null;
    }

    public ZipEntry(java.util.zip.ZipEntry entry) throws ZipException {
        super(entry.getName());
        this.internalAttributes = 0;
        this.platform = 0;
        this.externalAttributes = 0L;
        this.extraFields = new Vector();
        this.name = null;
        this.compressedSize = null;
        setComment(entry.getComment());
        setMethod(entry.getMethod());
        setTime(entry.getTime());
        long size = entry.getSize();
        if (size > 0) {
            setSize(size);
        }
        long cSize = entry.getCompressedSize();
        if (cSize > 0) {
            setComprSize(cSize);
        }
        long crc = entry.getCrc();
        if (crc > 0) {
            setCrc(crc);
        }
        byte[] extra = entry.getExtra();
        if (extra != null) {
            setExtraFields(ExtraFieldUtils.parse(extra));
        } else {
            setExtra();
        }
    }

    public ZipEntry(ZipEntry entry) throws ZipException {
        this((java.util.zip.ZipEntry) entry);
        setInternalAttributes(entry.getInternalAttributes());
        setExternalAttributes(entry.getExternalAttributes());
        setExtraFields(entry.getExtraFields());
    }

    /* JADX INFO: Access modifiers changed from: protected */
    public ZipEntry() {
        super("");
        this.internalAttributes = 0;
        this.platform = 0;
        this.externalAttributes = 0L;
        this.extraFields = new Vector();
        this.name = null;
        this.compressedSize = null;
    }

    @Override // java.util.zip.ZipEntry
    public Object clone() {
        try {
            ZipEntry e = (ZipEntry) super.clone();
            e.setName(getName());
            e.setComment(getComment());
            e.setMethod(getMethod());
            e.setTime(getTime());
            long size = getSize();
            if (size > 0) {
                e.setSize(size);
            }
            long cSize = getCompressedSize();
            if (cSize > 0) {
                e.setComprSize(cSize);
            }
            long crc = getCrc();
            if (crc > 0) {
                e.setCrc(crc);
            }
            e.extraFields = (Vector) this.extraFields.clone();
            e.setInternalAttributes(getInternalAttributes());
            e.setExternalAttributes(getExternalAttributes());
            e.setExtraFields(getExtraFields());
            return e;
        } catch (Throwable unused) {
            return null;
        }
    }

    public int getInternalAttributes() {
        return this.internalAttributes;
    }

    public void setInternalAttributes(int value) {
        this.internalAttributes = value;
    }

    public long getExternalAttributes() {
        return this.externalAttributes;
    }

    public void setExternalAttributes(long value) {
        this.externalAttributes = value;
    }

    public void setUnixMode(int mode) {
        setExternalAttributes((mode << 16) | ((mode & 128) == 0 ? 1 : 0) | (isDirectory() ? 16 : 0));
        this.platform = PLATFORM_UNIX;
    }

    public int getUnixMode() {
        return (int) ((getExternalAttributes() >> 16) & 65535);
    }

    public int getPlatform() {
        return this.platform;
    }

    /* JADX INFO: Access modifiers changed from: protected */
    public void setPlatform(int platform) {
        this.platform = platform;
    }

    public void setExtraFields(ZipExtraField[] fields) {
        this.extraFields.removeAllElements();
        for (ZipExtraField zipExtraField : fields) {
            this.extraFields.addElement(zipExtraField);
        }
        setExtra();
    }

    public ZipExtraField[] getExtraFields() {
        ZipExtraField[] result = new ZipExtraField[this.extraFields.size()];
        this.extraFields.copyInto(result);
        return result;
    }

    public void addExtraField(ZipExtraField ze) {
        ZipShort type = ze.getHeaderId();
        boolean done = false;
        for (int i = 0; !done && i < this.extraFields.size(); i++) {
            if (((ZipExtraField) this.extraFields.elementAt(i)).getHeaderId().equals(type)) {
                this.extraFields.setElementAt(ze, i);
                done = true;
            }
        }
        if (!done) {
            this.extraFields.addElement(ze);
        }
        setExtra();
    }

    public void removeExtraField(ZipShort type) {
        boolean done = false;
        for (int i = 0; !done && i < this.extraFields.size(); i++) {
            if (((ZipExtraField) this.extraFields.elementAt(i)).getHeaderId().equals(type)) {
                this.extraFields.removeElementAt(i);
                done = true;
            }
        }
        if (!done) {
            throw new NoSuchElementException();
        }
        setExtra();
    }

    @Override // java.util.zip.ZipEntry
    public void setExtra(byte[] extra) throws RuntimeException {
        try {
            setExtraFields(ExtraFieldUtils.parse(extra));
        } catch (Exception e) {
            throw new ZipRuntimeException(e.getMessage());
        }
    }

    protected void setExtra() {
        super.setExtra(ExtraFieldUtils.mergeLocalFileDataData(getExtraFields()));
    }

    public byte[] getLocalFileDataExtra() {
        byte[] extra = getExtra();
        return extra != null ? extra : new byte[0];
    }

    public byte[] getCentralDirectoryExtra() {
        return ExtraFieldUtils.mergeCentralDirectoryData(getExtraFields());
    }

    public void setComprSize(long size) {
        if (haveSetCompressedSize()) {
            performSetCompressedSize(this, size);
        } else {
            this.compressedSize = new Long(size);
        }
    }

    @Override // java.util.zip.ZipEntry
    public long getCompressedSize() {
        if (this.compressedSize != null) {
            return this.compressedSize.longValue();
        }
        return super.getCompressedSize();
    }

    @Override // java.util.zip.ZipEntry
    public String getName() {
        return this.name == null ? super.getName() : this.name;
    }

    @Override // java.util.zip.ZipEntry
    public boolean isDirectory() {
        return getName().endsWith("/");
    }

    /* JADX INFO: Access modifiers changed from: protected */
    public void setName(String name) {
        this.name = name;
    }

    private static boolean haveSetCompressedSize() {
        checkSCS();
        return setCompressedSizeMethod != null;
    }

    private static void performSetCompressedSize(ZipEntry ze, long size) {
        Long[] s = {new Long(size)};
        try {
            setCompressedSizeMethod.invoke(ze, s);
        } catch (InvocationTargetException ite) {
            Throwable nested = ite.getTargetException();
            throw new ZipRuntimeException("Exception setting the compressed size of " + ze + ": " + nested.getMessage());
        } catch (Throwable other) {
            throw new ZipRuntimeException("Exception setting the compressed size of " + ze + ": " + other.getMessage());
        }
    }

    /* JADX WARN: Multi-variable type inference failed */
    /* JADX WARN: Type inference failed for: r0v1, types: [java.lang.Object] */
    /* JADX WARN: Type inference failed for: r0v2, types: [java.lang.Throwable] */
    /* JADX WARN: Type inference failed for: r0v4 */
    private static void checkSCS() {
        if (!triedToGetMethod) {
            ?? r0 = lockReflection;
            synchronized (r0) {
                triedToGetMethod = true;
                try {
                    setCompressedSizeMethod = java.util.zip.ZipEntry.class.getMethod("setCompressedSize", Long.TYPE);
                } catch (NoSuchMethodException unused) {
                }
                r0 = r0;
            }
        }
    }
}
